@@ -12,6 +12,16 @@
 #ifndef GAMGI_CHEM
 #define GAMGI_CHEM
 
+/********** types *********
+ **************************/
+
+/********************************************************************
+ * These types define pointers to radial and angular H wavefunctions *
+ *********************************************************************/
+
+typedef double (*gamgi_radial) (double r);
+typedef double (*gamgi_angular) (double x, double y, double z, double r);
+
 /************* macros ************
  *********************************/
 
@@ -259,4 +269,42 @@ GAMGI_CHEM_FILTER_IDENTICAL, GAMGI_CHEM_FILTER_NONE };
 #define GAMGI_CHEM_POLYTOPE_VISIBLE_MAX  1.0E-05
 #define GAMGI_CHEM_POLYTOPE_COPLANAR_MAX 1.0E-01
 
+/*************************
+ * Bohr first radius     *
+ * default atomic charge *
+ *************************/
+
+#define GAMGI_CHEM_A0 0.52917720858
+#define GAMGI_CHEM_CHARGE_Z 1.0
+
+/**************************************************
+ * used to calculate optimum radius in H orbitals *
+ **************************************************/
+
+#define GAMGI_CHEM_ORBITAL_SHIFT 2.0
+#define GAMGI_CHEM_ORBITAL_MAX  50.0
+#define GAMGI_CHEM_ORBITAL_STEP 0.01
+
+/*************************************************************
+ * used to build dotted H orbitals: default density,         *
+ * default number of points / n (main quantum number),       *
+ * number of acceptable bad points (below density threshold) *
+ *************************************************************/
+
+#define GAMGI_CHEM_ORBITAL_DENSITY 1.0E-6
+#define GAMGI_CHEM_ORBITAL_POINTS   50000
+#define GAMGI_CHEM_ORBITAL_BAD       1000
+
+/***************************************
+ * default orbital origin, orientation *
+ ***************************************/
+
+#define GAMGI_CHEM_ORBITAL_X 0.0
+#define GAMGI_CHEM_ORBITAL_Y 0.0
+#define GAMGI_CHEM_ORBITAL_Z 0.0
+
+#define GAMGI_CHEM_ORBITAL_E1 0.0
+#define GAMGI_CHEM_ORBITAL_E2 0.0
+#define GAMGI_CHEM_ORBITAL_E3 0.0
+
 #endif
