@@ -151,10 +151,37 @@ typedef struct _gamgi_orbital {
 gamgi_object object;
 void (*draw) (struct _gamgi_orbital *);
 
+/****************
+ * quantum data *
+ ****************/
+
+int n, l, m;
+double charge;
+double radius, density;
+
+/**************
+ * array data *
+ **************/
+
+int dots[3];
+double *points;
+int *lines;
+int n_points, n_lines;
+
+/*********************************
+ * style, axes, colors, position *
+ *********************************/
+
+gamgi_enum style;
+gamgi_bool axes;
+double length;
+
 double origin[3];
 double center[3];
 double quaternion[4];
 
+float base[3], phase[3], frame[3];
+
 gamgi_dlist *text_start;
 gamgi_dlist *text_end;
 struct _gamgi_orbital *next, *before; } gamgi_orbital;
@@ -357,7 +384,7 @@ gamgi_object object;
 int mark;
 
 gamgi_enum type;
-gamgi_bool faces, dots;
+gamgi_bool faces;
 
 double origin[3], center[3];
 double quaternion[4];
