@@ -75,9 +75,76 @@ text_new->blue = text->blue;
 
 void gamgi_engine_copy_out_orbital (gamgi_orbital *orbital, gamgi_orbital *orbital_new)
 {
-static_copy (GAMGI_CAST_OBJECT orbital, GAMGI_CAST_OBJECT orbital_new);
+int i;
 
+static_copy (GAMGI_CAST_OBJECT orbital, GAMGI_CAST_OBJECT orbital_new);
 orbital_new->draw = orbital->draw;
+
+orbital_new->n = orbital->n;
+orbital_new->l = orbital->l;
+orbital_new->m = orbital->m;
+
+orbital_new->charge = orbital->charge;
+orbital_new->radius = orbital->radius;
+orbital_new->density = orbital->density;
+
+orbital_new->dots[0] = orbital->dots[0];
+orbital_new->dots[1] = orbital->dots[1];
+orbital_new->dots[2] = orbital->dots[2];
+
+orbital_new->style = orbital->style;
+orbital_new->axes = orbital->axes;
+orbital_new->length = orbital->length;
+
+/**************************************
+ * copy position and orientation data *
+ **************************************/
+
+orbital_new->origin[0] = orbital->origin[0];
+orbital_new->origin[1] = orbital->origin[1];
+orbital_new->origin[2] = orbital->origin[2];
+
+orbital_new->center[0] = orbital->center[0];
+orbital_new->center[1] = orbital->center[1];
+orbital_new->center[2] = orbital->center[2];
+
+orbital_new->quaternion[0] = orbital->quaternion[0];
+orbital_new->quaternion[1] = orbital->quaternion[1];
+orbital_new->quaternion[2] = orbital->quaternion[2];
+orbital_new->quaternion[3] = orbital->quaternion[3];
+
+/******************************
+ * copy arrays: points, lines *
+ ******************************/
+
+orbital_new->points = NULL;
+i = 3 * orbital->n_points;
+if (i != 0) orbital_new->points = (double *) malloc (sizeof (double) * i);
+while (i-- > 0) orbital_new->points[i] = orbital->points[i];
+
+orbital_new->lines = NULL;
+i = orbital->n_lines;
+if (i != 0) orbital_new->lines = (int *) malloc (sizeof (int) * i);
+while (i-- > 0) orbital_new->lines[i] = orbital->lines[i];
+
+orbital_new->n_points = orbital->n_points;
+orbital_new->n_lines = orbital->n_lines;
+
+/**************************
+ * copy color information *
+ **************************/
+
+orbital_new->base[0] = orbital->base[0];
+orbital_new->base[1] = orbital->base[1];
+orbital_new->base[2] = orbital->base[2];
+
+orbital_new->phase[0] = orbital->phase[0];
+orbital_new->phase[1] = orbital->phase[1];
+orbital_new->phase[2] = orbital->phase[2];
+
+orbital_new->frame[0] = orbital->frame[0];
+orbital_new->frame[1] = orbital->frame[1];
+orbital_new->frame[2] = orbital->frame[2];
 }
 
 void gamgi_engine_copy_out_bond (gamgi_bond *bond, gamgi_bond *bond_new)
@@ -423,7 +490,6 @@ cluster_new->n_dots = cluster->n_dots;
  *************/
 
 cluster_new->faces = cluster->faces;
-cluster_new->dots = cluster->dots;
 }
 
 void gamgi_engine_copy_out_cell (gamgi_cell *cell, gamgi_cell *cell_new)
