@@ -103,6 +103,41 @@ orbital->object.number = gamgi_engine_number_orbital_get ();
  **********************/
 
 orbital->draw = NULL;
+
+orbital->n = 0;
+orbital->l = 0;
+orbital->m = 0;
+
+orbital->charge = 0.0;
+orbital->radius = 0.0;
+orbital->density = 0.0;
+
+orbital->dots[0] = 0;
+orbital->dots[1] = 0;
+orbital->dots[2] = 0;
+
+orbital->points = NULL;
+orbital->lines= NULL;
+orbital->n_points = 0;
+orbital->n_lines = 0;
+
+orbital->origin[0] = 0.0;
+orbital->origin[1] = 0.0;
+orbital->origin[2] = 0.0;
+
+orbital->center[0] = 0.0;
+orbital->center[1] = 0.0;
+orbital->center[2] = 0.0;
+
+orbital->quaternion[0] = 0.0;
+orbital->quaternion[1] = 0.0;
+orbital->quaternion[2] = 0.0;
+orbital->quaternion[3] = 1.0;
+
+orbital->draw = NULL;
+orbital->style = FALSE;
+orbital->axes = FALSE;
+orbital->length = 0.0;
 }
 
 /**** external function *****
@@ -414,7 +449,6 @@ cluster->n_paints = 0;
 cluster->n_dots = 0;
 
 cluster->faces = FALSE;
-cluster->dots = FALSE;
 }
 
 /***** external function ****
