@@ -90,12 +90,13 @@ switch (window->action)
 
   case GAMGI_GTK_ORBITAL_CREATE:
   gamgi_gtk_help_dialog_import ("Help Orbital Create",  
-  "interfaces/orbital/create", window, 0, n);
+  "interfaces/orbital/create", window, 5, n,
+  "type", "model", "volume", "position", "view");
   break;
 
   case GAMGI_GTK_ORBITAL_COPY:
   gamgi_gtk_help_dialog_import ("Help Orbital Copy",  
-  "interfaces/orbital/copy", window, 0, n);
+  "interfaces/orbital/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_ORBITAL_SELECT:
@@ -105,7 +106,7 @@ switch (window->action)
 
   case GAMGI_GTK_ORBITAL_LINK:
   gamgi_gtk_help_dialog_import ("Help Orbital Link",  
-  "interfaces/orbital/link", window, 0, n);
+  "interfaces/orbital/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_ORBITAL_MODIFY:
@@ -115,7 +116,7 @@ switch (window->action)
 
   case GAMGI_GTK_ORBITAL_REMOVE:
   gamgi_gtk_help_dialog_import ("Help Orbital Remove",  
-  "interfaces/orbital/remove", window, 0, n);
+  "interfaces/orbital/remove", window, 1, n, "object");
   break;
 
   case GAMGI_GTK_BOND_CREATE:
@@ -221,8 +222,8 @@ switch (window->action)
 
   case GAMGI_GTK_DIRECTION_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Direction Modify",  
-  "interfaces/direction/modify", window, 4, n, "type",
-  "projection", "scope", "view");
+  "interfaces/direction/modify", window, 5, n, "type",
+  "projection", "scope", "position", "view");
   break;
 
   case GAMGI_GTK_DIRECTION_MEASURE:
@@ -258,8 +259,8 @@ switch (window->action)
 
   case GAMGI_GTK_PLANE_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Plane Modify",  
-  "interfaces/plane/modify", window, 4, n, "type",
-  "projection", "scope", "view");
+  "interfaces/plane/modify", window, 5, n, "type",
+  "projection", "scope", "position", "view");
   break;
 
   case GAMGI_GTK_PLANE_MEASURE:
@@ -274,8 +275,8 @@ switch (window->action)
 
   case GAMGI_GTK_GROUP_CREATE:
   gamgi_gtk_help_dialog_import ("Help Group Create",  
-  "interfaces/group/create", window, 4, n, "type",
-  "scope", "tolerance", "view");
+  "interfaces/group/create", window, 3, n, "type",
+  "scope", "view");
   break;
 
   case GAMGI_GTK_GROUP_CREATE_POLYTOPE:
@@ -301,7 +302,7 @@ switch (window->action)
   case GAMGI_GTK_GROUP_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Group Modify",  
   "interfaces/group/modify", window, 4, n, "type", 
-  "scope", "tolerance", "view");
+  "scope", "position", "view");
   break;
 
   case GAMGI_GTK_GROUP_MODIFY_POLYTOPE:
