@@ -191,7 +191,7 @@ if (scope < 1)
   gamgi->windows = NULL;
 
   if (gamgi->window_start->window != NULL)
-    gamgi_global_selection_hide ("button_window");
+    gamgi_global_selection_update_windows (&gamgi->windows, "button_window");
   }
 }
 
