@@ -101,8 +101,8 @@ GAMGI_IO_DEJAVU_MONO_ITALIC, GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC };
  * the Gamgi->About GUI dialog *
  *******************************/
 
-#define GAMGI_IO_DATE "6th June 2012"
-#define GAMGI_IO_VERSION "0.15.8"
+#define GAMGI_IO_DATE "14th January 2013"
+#define GAMGI_IO_VERSION "0.16.3"
 #define GAMGI_IO_AUTHORS "Carlos Pereira et al."
 #define GAMGI_IO_LICENSE "GPL"
 #define GAMGI_IO_WEBSITE "http://www.gamgi.org/"
