@@ -951,7 +951,7 @@ if (cluster->loops != NULL)
 
   gamgi_io_file_fprintf (fp, "</Shape>\n", error);
 
-  if (cluster->dots == TRUE)
+  if (cluster->n_dots > 0)
     gamgi_io_x3d_render_points (fp, cluster->n_dots, 
     cluster->points, cluster->colors, error);
 
