@@ -72,15 +72,60 @@ glPopMatrix ();
 void gamgi_mesa_draw_orbital (gamgi_orbital *orbital) 
 {
 gamgi_dlist *dlist;
+double rotate[16];
+double *center;
+double scale;
+int *dots;
+
+glPushMatrix ();
+
+center = orbital->center;
+scale = orbital->object.scale;
+
+glTranslatef (center[0], center[1], center[2]);
+glScalef (scale, scale, scale);
+glTranslatef (-center[0], -center[1], -center[2]);
+
+glPushMatrix ();
+
+glTranslatef (orbital->origin[0], orbital->origin[1], orbital->origin[2]);
+
+gamgi_math_quaternion_to_matrix4 (orbital->quaternion, rotate);
+glMultMatrixd (rotate);
+
+/***********************
+ * draw orbital object *
+ ***********************/
+
+dots = orbital->dots;
+
+glLineWidth (4.0);
+if (dots[1] > 0)
+  { glColor3fv (orbital->base);
+    gamgi_mesa_render_points (dots[1], orbital->points + 3 * dots[0]); }
+if (dots[2] > 0)
+  { glColor3fv (orbital->phase);
+    gamgi_mesa_render_points (dots[2], orbital->points + 3 * dots[0] + 3 * dots[1]); }
+glLineWidth (1.0);
+
+if (dots[0] > 0)
+  { glColor3fv (orbital->frame);
+    gamgi_mesa_render_lines (orbital->lines, orbital->points); }
+if (orbital->axes == TRUE)
+  gamgi_mesa_axes_orbital (orbital, TRUE);
 
 /******************
  * draw text list *
  ******************/
 
+glPopMatrix ();
+
 dlist = orbital->text_start;
 while (dlist != NULL)
   { gamgi_mesa_draw_text (GAMGI_CAST_TEXT dlist->data);
     dlist = dlist->next; }
+
+glPopMatrix ();
 }
 
 void gamgi_mesa_draw_bond (gamgi_bond *bond, gamgi_atom *atom) 
@@ -669,7 +714,7 @@ else
 
   gamgi_mesa_render_loops (cluster->loops, cluster->points);
 
-  if (cluster->dots == TRUE)
+  if (cluster->n_dots > 0)
     gamgi_mesa_render_points (cluster->n_dots, cluster->points);
 
   glDisable (GL_POLYGON_OFFSET_FILL);
