@@ -24,6 +24,10 @@
 #include "gamgi_gtk_text_link.h"
 #include "gamgi_gtk_text_modify.h"
 #include "gamgi_gtk_text_remove.h"
+#include "gamgi_gtk_orbital_create.h"
+#include "gamgi_gtk_orbital_copy.h"
+#include "gamgi_gtk_orbital_link.h"
+#include "gamgi_gtk_orbital_remove.h"
 #include "gamgi_gtk_bond_create.h"
 #include "gamgi_gtk_bond_select.h"
 #include "gamgi_gtk_bond_link.h"
@@ -629,6 +633,28 @@ switch (window_dialog->action)
   gamgi_gtk_text_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
+  case GAMGI_GTK_ORBITAL_CREATE:
+  gamgi_gtk_orbital_create_press (window_mouse, event, x, y, window_dialog);
+  return TRUE;
+
+  case GAMGI_GTK_ORBITAL_COPY:
+  gamgi_gtk_orbital_copy_press (window_mouse, event, x, y, window_dialog);
+  return TRUE;
+
+  case GAMGI_GTK_ORBITAL_SELECT:
+  return TRUE;
+
+  case GAMGI_GTK_ORBITAL_LINK:
+  gamgi_gtk_orbital_link_press (window_mouse, event, x, y, window_dialog);
+  return TRUE;
+
+  case GAMGI_GTK_ORBITAL_MODIFY:
+  return TRUE;
+
+  case GAMGI_GTK_ORBITAL_REMOVE:
+  gamgi_gtk_orbital_remove_press (window_mouse, event, x, y, window_dialog);
+  return TRUE;
+
   case GAMGI_GTK_BOND_CREATE:
   gamgi_gtk_bond_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
